From: TRANS Date: 2005-12-02T04:39:58+09:00 Subject: Pathname implementation using Array Any interest in this reimplementation of Pathname that uses an Array instead of a String? It's based on the current standard version in Ruby, I just changed @path from a string to and array and adjusted the rst of the code as needed. It appears to be about 20% faster. And it can be made even more flexiable too, I've already added #<< (which is what I've been wanting) and other methods could be easily added like #pop, #shift, and even include Enumerable if desired. Also, now that @path is an Array, it might not hurt to go the next step and make Pathname a subclass of Array instead, that'd probably make it a tad bit faster again. Still, I imagine Pathname should ultimately be coded-up in C, nontheless using an Array as the core data contatiner instead of a Sting looks to be a nice improvement. T.